<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>RenameBlock</name>
    <message>
        <location filename="../RenameBlockInit.js" line="+2"/>
        <source>Re&amp;name Block</source>
        <translation>&amp;Rinomina blocco</translation>
    </message>
</context>
</TS>
